exit_alt_screen

Function exit_alt_screen 

pub fn exit_alt_screen() -> Cmd
Creates a command that exits the alternate screen buffer.

This command sends an ExitAltScreenMsg to the program, which will cause the terminal to switch back from the alternate screen buffer.