pub fn printf(s: String) -> Cmd
Creates a command that prints formatted text to the terminal.
This command sends a PrintfMsg to the program, which will print the provided formatted string to the terminal.
PrintfMsg