suspend

Function suspend 

pub fn suspend() -> Cmd
Creates a command that suspends the application.

This command sends a SuspendMsg to the program, which can be used to temporarily pause the application and release terminal control.