pub struct KillMsg;Expand description
A message to forcefully kill the application immediately.
Sending this message to the Program will cause it to terminate as soon as
possible. The event loop will stop without invoking the model’s update and
will return an Error::ProgramKilled.