pub struct SuspendMsg;Expand description
A message to signal the application to suspend.
This can be used to temporarily pause the application, for example, when another process needs control of the terminal.