pub enum MouseMotion {
None,
Cell,
All,
}Expand description
Defines the different modes for mouse motion reporting.
Variants
None
No mouse motion events are reported.
Cell
Mouse motion events are reported when the mouse moves over a different cell.
All
Mouse motion events are reported for every pixel movement.