pub fn enable_mouse_all_motion() -> Cmd
Creates a command that enables all mouse motion reporting.
This command sends an EnableMouseAllMotionMsg to the program, which will enable all mouse events in the terminal.
EnableMouseAllMotionMsg