pub fn enable_mouse_cell_motion() -> CmdExpand description
Creates a command that enables mouse cell motion reporting.
This command sends an EnableMouseCellMotionMsg to the program, which will
enable mouse events for individual cells in the terminal.